@@ -8,7 +8,6 @@ from .connexio import JManCon, ConfigJavaman
 
 
 class JMan:
-
     __slots__ = '_con'
 
     def __init__(self, config_data: dict):
@@ -94,6 +93,9 @@ class JManFb:
     def c_sync_clients(self):
         return self.select(sql=fb_consultes.sync_clients)
 
+    def c_sync_proveidors(self):
+        return self.select(sql=fb_consultes.sync_proveidors)
+
     def c_sync_clients_mrest(self):
         return self.select(sql=fb_consultes.sync_clients_mrest)
 
@@ -119,4 +121,4 @@ class JManFb:
         return self.select(sql=fb_consultes.sync_comanda, args=(comanda_id,))[0]
 
     def c_sync_comanda_linies(self, comanda_id: int, magatzem_id: int):
-        return self.select(sql=fb_consultes.sync_comanda_linies, args=(comanda_id,magatzem_id))
+        return self.select(sql=fb_consultes.sync_comanda_linies, args=(comanda_id, magatzem_id))
