@@ -25,6 +25,12 @@ join tercers t on c.TERCER_ID = t.ID
 join tercers_parametres tp on t.id = tp.tercer_id
 """
 
+sync_proveidors = """
+select p.EMPRESA_ID, t.ID, p.ID, t.NOM_LLARG_I_COMERCIAL, p.DATA_BAIXA
+from proveidors p
+join tercers t on p.TERCER_ID = t.ID
+"""
+
 sync_condicions_pagament = """
   select c.ID, c.condicio_pagament
     from condicions_pagament c
